#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SQR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SQR_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/sqr.hpp>

#endif
